@@ -36,3 +36,11 @@ class HtmlFile(Path):
 			self._spoon = Spoon(soup=self.soup)
 		return self._spoon
 
+	def extract_soup(self):
+		"""
+		:rtype: BeautifulSoup
+		"""
+		soup = self.soup
+		self._soup = None
+		self._spoon = None
+		return soup
