@@ -12,18 +12,23 @@ from .get_text import get_text
 
 
 class BaseHtmlText:
-	def __init__(self, obj, id, ignore_function=None, depth=0, _ids=None, log=None, num_jobs=1):
+	def __init__(self, obj, _id, extract_tags, ignore_function=None, depth=0, ids=None, log=None, num_jobs=1):
 		"""
-		:type obj: 				Tag or BaseHtmlText
+		:type obj: 				Tag or BaseHtmlText or Pdf
 		:type ignore_function: 	Callable or NoneType
 		"""
 		if isinstance(obj, BaseHtmlText):
 			ignore_function = ignore_function or obj._ignore_function
 			depth = max(depth, obj._production_depth)
 			obj = obj._tag
+			if extract_tags:
+				obj._tag = None
 		else:
 			try:
-				obj = obj.html_file.soup
+				if extract_tags:
+					obj = obj.html_file.extract_soup()
+				else:
+					obj = obj.html_file.soup
 			except AttributeError:
 				pass
 
@@ -38,7 +43,7 @@ class BaseHtmlText:
 		self._production_depth = depth
 		self._ignore_function = ignore_function
 		self._index = None
-		self._ids = _ids or {}
+		self._ids = ids or {}
 		self._num_jobs = num_jobs
 
 		if log is None or log is False or log == 0:
@@ -48,9 +53,9 @@ class BaseHtmlText:
 		else:
 			self._logs = []
 
-		self._id = str(id)
+		self._id = str(_id)
 		self._ids[self.id] = self
-		self.parse(tag=obj)
+		self.parse(tag=obj, extract_tags=extract_tags)
 
 	@classmethod
 	def _get_state_attribute_names(cls):
@@ -98,10 +103,10 @@ class BaseHtmlText:
 		for child in self.children:
 			child._set_logs(logs=logs)
 
-	def _set_ids(self, _ids):
-		self._ids = _ids
+	def _set_ids(self, ids):
+		self._ids = ids
 		for child in self.children:
-			child._set_ids(_ids=_ids)
+			child._set_ids(ids=ids)
 
 	def delete(self, by):
 		if self.id is not None:
@@ -316,19 +321,20 @@ class BaseHtmlText:
 	def is_only_parent(self):
 		return self._string is None and self.num_children > 0
 
-	def parse(self, tag):
-		tag_children = get_children(tag, ignore_single_children=False)
+	def parse(self, tag, extract_tags):
+		tag_children = get_children(tag, ignore_single_children=False, extract=extract_tags)
 		if tag_children is None:
 			tag_children = []
 		if len(tag_children) == 0:
 			self.string = (get_text(tag) or '').lstrip('-*\t .')
 
 		else:
-			self.parse_children(tag_children=tag_children)
+			self.parse_children(tag_children=tag_children, extract_tags=extract_tags)
 
 	def absorb_children(self, other, by):
 		"""
 		:type other: BaseHtmlText
+		:type by: BaseHtmlText
 		"""
 		self.log(message=f'absorb children of {other}', by=by)
 		for child in other.children:
@@ -355,6 +361,9 @@ class BaseHtmlText:
 				prev_child._font_size = prev_child._font_size or child._font_size
 
 	def absorb_font_and_style(self, html_text):
+		"""
+		:type html_text: BaseHtmlText
+		"""
 		self._font_size = html_text._font_size or self._font_size
 		if self._style is None:
 			self._style = html_text._style
@@ -401,31 +410,32 @@ class BaseHtmlText:
 		else:
 			self.log(message=f'cannot absorb anything from child {single_child.id}', by=self)
 
-	def _get_tag_and_child(self, tag, num_jobs, child_id):
+	def _get_tag_and_child(self, tag, num_jobs, child_id, extract_tags):
 		base_html_text = BaseHtmlText(
 			obj=tag,
-			id=f'{self.id}.{child_id}',
+			_id=f'{self.id}.{child_id}',
 			depth=self._production_depth + 1,
 			log=self._logs,
-			_ids=self._ids,
+			ids=self._ids,
+			extract_tags=extract_tags,
 			num_jobs=num_jobs
 		)
 		return tag, base_html_text
 
-	def get_tags_and_children(self, tag_children):
+	def get_tags_and_children(self, tag_children, extract_tags):
 		num_jobs_remaining = self._num_jobs - 1
 		num_jobs_per_child = divide_into_almost_equal_parts(number=num_jobs_remaining, by=len(tag_children))
 		child_ids = [i + 1 for i in range(len(tag_children))]
 
 		if self._num_jobs < 2:
 			tags_and_children = [
-				self._get_tag_and_child(tag=_tag, num_jobs=1, child_id=_child_id)
+				self._get_tag_and_child(tag=_tag, num_jobs=1, child_id=_child_id, extract_tags=extract_tags)
 				for _tag, _child_id in zip(tag_children, child_ids)
 			]
 
 		elif any([x < 1 for x in num_jobs_per_child]):
 			tags_and_children = [
-				self._get_tag_and_child(tag=_tag, num_jobs=1, child_id=_child_id)
+				self._get_tag_and_child(tag=_tag, num_jobs=1, child_id=_child_id, extract_tags=extract_tags)
 				for _tag, _child_id in zip(tag_children, child_ids)
 			]
 
@@ -434,15 +444,20 @@ class BaseHtmlText:
 
 			processor = Parallel(n_jobs=self._num_jobs, backend='threading', require='sharedmem')
 			tags_and_children = processor(
-				delayed(self._get_tag_and_child)(tag=_tag, num_jobs=int(_num_jobs), child_id=_child_id)
+				delayed(self._get_tag_and_child)(
+					tag=_tag,
+					num_jobs=int(_num_jobs),
+					child_id=_child_id,
+					extract_tags=extract_tags
+				)
 				for _tag, _num_jobs, _child_id in tags_and_num_jobs_and_ids
 			)
 
 		return tags_and_children
 
-	def parse_children(self, tag_children):
+	def parse_children(self, tag_children, extract_tags):
 
-		tags_and_children = self.get_tags_and_children(tag_children=tag_children)
+		tags_and_children = self.get_tags_and_children(tag_children=tag_children, extract_tags=extract_tags)
 
 		for tag, child in tags_and_children:
 			prev_child = self.last_child
@@ -554,7 +569,6 @@ class BaseHtmlText:
 			'text': self.string,
 			**self.style
 		}
-		return
 
 	@property
 	def records(self):
