@@ -6,8 +6,17 @@ from .StructuredText import StructuredText
 
 
 class HtmlText(BaseHtmlText):
-	def __init__(self, obj, ignore_function=None, log=False, num_jobs=1):
-		super().__init__(obj=obj, id='1', ignore_function=ignore_function, depth=0, _ids=None, log=log, num_jobs=num_jobs)
+	def __init__(self, obj, extract_tags, ignore_function=None, log=False, num_jobs=1):
+		super().__init__(
+			obj=obj,
+			extract_tags=extract_tags,
+			_id='1',
+			ignore_function=ignore_function,
+			depth=0,
+			ids=None,
+			log=log,
+			num_jobs=num_jobs
+		)
 		self._data = None
 		self._font_size_data = None
 		self._font_sizes = None
@@ -29,7 +38,7 @@ class HtmlText(BaseHtmlText):
 	def __setstate__(self, state):
 		super().__setstate__(state=state)
 		self._set_logs(logs=self._logs)
-		self._set_ids(_ids=self._ids)
+		self._set_ids(ids=self._ids)
 
 	def __getstate__(self):
 		state = super().__getstate__()
