@@ -1,7 +1,7 @@
 from .is_break import is_break
 
 
-def get_children(tag, ignore_single_children=True):
+def get_children(tag, ignore_single_children=True, extract=False):
 	"""
 	:type tag: Tag or list or tuple
 	:rtype: NoneType or list[Tag]
@@ -13,6 +13,8 @@ def get_children(tag, ignore_single_children=True):
 		return None
 	else:
 		children = [x for x in tag.children if x is not None and x != []]
+		if extract:
+			children = [x.extract() for x in children]
 
 		# remove repeated breaks
 		new_children = []
